# Reputation

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cache_versn** | **int** |  | [optional] 
**commit_message** | **str** |  | [optional] 
**context_path** | **str** |  | [optional] 
**context_value** | **str** |  | [optional] 
**default_mapping** | [**dict(str, AdvanceArg)**](AdvanceArg.md) |  | [optional] 
**definition_id** | **str** |  | [optional] 
**details** | **str** |  | [optional] 
**disabled** | **bool** |  | [optional] 
**enhancement_script_names** | **list[str]** |  | [optional] 
**excluded_brands** | **list[str]** |  | [optional] 
**expiration** | **int** |  | [optional] 
**file** | **bool** |  | [optional] 
**file_hashes_priority** | **list[str]** |  | [optional] 
**format_script** | **str** |  | [optional] 
**from_server_version** | [**Version**](Version.md) |  | [optional] 
**highlight** | **dict(str, list[str])** |  | [optional] 
**id** | **str** |  | [optional] 
**item_version** | [**Version**](Version.md) |  | [optional] 
**layout** | **str** |  | [optional] 
**legacy_names** | **list[str]** |  | [optional] 
**locked** | **bool** |  | [optional] 
**manual_mapping** | [**dict(str, AdvanceArg)**](AdvanceArg.md) |  | [optional] 
**merge_context** | **bool** |  | [optional] 
**modified** | **datetime** |  | [optional] 
**numeric_id** | **int** |  | [optional] 
**pack_id** | **str** |  | [optional] 
**pack_name** | **str** |  | [optional] 
**pack_propagation_labels** | **list[str]** |  | [optional] 
**prev_details** | **str** |  | [optional] 
**primary_term** | **int** |  | [optional] 
**propagation_labels** | **list[str]** |  | [optional] 
**regex** | **str** |  | [optional] 
**remote** | **bool** |  | [optional] 
**reputation_command** | **str** |  | [optional] 
**reputation_script_name** | **str** |  | [optional] 
**sequence_number** | **int** |  | [optional] 
**should_commit** | **bool** |  | [optional] 
**should_share_comments** | **bool** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**sync_hash** | **str** |  | [optional] 
**system** | **bool** |  | [optional] 
**to_server_version** | [**Version**](Version.md) |  | [optional] 
**update_after** | **int** |  | [optional] 
**vc_should_ignore** | **bool** |  | [optional] 
**vc_should_keep_item_legacy_prod_machine** | **bool** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


